Index: include.preload.js |
=================================================================== |
--- a/include.preload.js |
+++ b/include.preload.js |
@@ -409,8 +409,8 @@ |
// have to create the shadow root before transistions might start (#452). |
// |
// Also, using shadow DOM causes issues on some Google websites, |
- // including Google Docs and Gmail (#1770, #2602). |
- if ("createShadowRoot" in document.documentElement && !/\.google\.com$/.test(document.domain)) |
+ // including Google Docs, Gmail and Blogger (#1770, #2602, #2687). |
+ if ("createShadowRoot" in document.documentElement && !/\.(?:google|blogger)\.com$/.test(document.domain)) |
kzar
2016/03/19 15:16:59
Nit: Mind fixing this long line?
Sebastian Noack
2016/03/19 15:20:11
Done.
|
{ |
shadow = document.documentElement.createShadowRoot(); |
shadow.appendChild(document.createElement("shadow")); |